#!/usr/local/bin/tsipp
#
# Generate a scene to show the affect of the positioning of the camera.
# -misc argument should contain a letter indicating which view to generate.
#
# $Id: camera.tcl,v 1.4 1996/11/08 18:11:45 markd Exp $
#

source ../utils.tcl

ParseArgs

switch -- $misc {
    {a} {
        # Distance from point to look = 7.0
        set cameraPoint {0.0 0.0 7.0}
        set cameraLook {0.0 0.0 0.0}
        set focal 0.2
    }
    {b} {
        # Distance from point to look = 7.07
        set cameraPoint {5.0 0.0 5.0}
        set cameraLook {0.0 0.0 0.0}
        set focal 0.2
    }
    {c} {
        # Distance from point to look = 7.07
        set cameraPoint {4.0 5.0 3.0}
        set cameraLook {0.0 0.0 0.0}
        set focal 0.2
    }
    {d} {
        # Distance from point to look = 10.07
        set cameraPoint {6.0 7.5 4.5}
        set cameraLook {1.0 0.0 0.0}
        set focal 0.2
    }
    {e} {
        # Distance from point to look = 6.56
        set cameraPoint {4.0 5.0 3.0}
        set cameraLook {1.0 0.0 0.0}
        set focal 0.3
    }
    default {
        puts stderr "Invalid or missing -misc argument"
        exit 1
    }
}

#
# Define the block at the world center.
#
set bshader [SippShaderBasic 0.4 0.6 0.2 {0.0 0.0 1.0}]
set block [SippBlock {2.5 1.0 0.5} $bshader]
SippObjectAddSubobj WORLD $block

#
# Define a sphere on the positive X axis.
#
set sshader [SippShaderBasic 0.4 0.7 0.1 {0.8 0.6 0.3}]
set bumpy [SippShaderBumpy $sshader 14.0 HOLES]
set sphere [SippSphere 0.5 25 $bumpy WORLD]
SippObjectMove $sphere {2.6 0.0 0.0}
SippObjectAddSubobj WORLD $sphere

StdLights {-15.0  15.0 15.0} {0.5 0.5 0.5}
StdLights {-15.0 -15.0 15.0} {0.5 0.5 0.5}
StdRender $cameraPoint $cameraLook $focal

